@@ -292,7 +292,7 @@ sub initialize_samples {
 
     my ($local_gzip, $file, $prefix, $suffix, $path, $found, $i);
 
-    if (length(scalar(@{$sample_list})) > 0 && scalar(@{$samples}) == 0) {
+    if (scalar(@{$sample_list}) > 0 && scalar(@{$samples}) == 0) {
         my @suffixes = ("sam", "bam", "map", "bowtie");
         my @fmts     = ("sam", "bam", "map", "bowtie");
 
@@ -365,13 +365,13 @@ sub initialize_samples {
             }
         }
 
-        foreach $sample (@parents) {
+        foreach $sample (@{$parents}) {
             $sample->{'type'} = "parent";
         }
-        foreach $sample (@progeny) {
+        foreach $sample (@{$progeny}) {
             $sample->{'type'} = "progeny";
         }
-        foreach $sample (@samples) {
+        foreach $sample (@{$samples}) {
             $sample->{'type'} = "sample";
         }
     }
@@ -872,7 +872,7 @@ sub usage {
     version();
 
     print STDERR <<EOQ; 
-ref_map.pl -p path -r path [-s path] -o path [-t] [-m min_cov] [-M mismatches] [-n mismatches] [-T num_threads] [-A type] [-O popmap] [-B db -b batch_id -D "desc"] [-S -i num] [-e path] [-d] [-h]
+ref_map.pl -p path -r path [-s path] -o path [-t] [-m min_cov] [-M mismatches] [-T num_threads] [-A type] [-O popmap] [-B db -b batch_id -D "desc"] [-S -i num] [-e path] [-d] [-h]
     b: batch ID representing this dataset (an integer, e.g. 1, 2, 3).
     o: path to write pipeline output files.
     O: if analyzing one or more populations, specify a pOpulation map.
