@@ -21,7 +21,9 @@
 #ifndef __POPMAP_H__
 #define __POPMAP_H__
 
-#include <string.h>
+#include <exception>
+using std::exception;
+#include <cstring>
 #include <string>
 using std::string;
 #include <vector>
@@ -30,6 +32,8 @@ using std::vector;
 using std::map;
 #include <set>
 using std::set;
+#include <numeric>
+using std::accumulate;
 #include <algorithm>
 #include <utility>
 using std::pair;
@@ -38,6 +42,8 @@ using std::make_pair;
 #include "stacks.h"
 #include "locus.h"
 #include "aln_utils.h"
+#include "MetaPopInfo.h"
+#include "Vcf.h"
 
 class Datum {
 public:
@@ -53,8 +59,9 @@ public:
     char          *cigar;         // CIGAR string describing how the datum aligns to the catalog locus.
     double         lnl;           // Log likelihood of this locus.
     vector<char *> obshap;        // Observed Haplotypes
-    vector<SNP *>  snps;
+    vector<SNP *>  snps;          // All calls for this sample for this locus. size() is [len].
     Datum()  {
+        this->id            = -1;
         this->corrected     = false;
         this->gtype         = NULL;
         this->trans_gtype   = NULL;
@@ -97,57 +104,69 @@ public:
 
 template<class LocusT=Locus>
 class PopMap {
-    set<pair<int, int> > blacklist;
+    const MetaPopInfo& metapopinfo;
     int      num_loci;
-    int      num_samples;
+    set<pair<int, int> > blacklist;
     Datum ***data;
     map<int, int> locus_order;  // LocusID => ArrayIndex; map catalog IDs to their first dimension 
                                 // position in the Datum array.
     map<int, int> rev_locus_order;
-    map<int, int> sample_order; // SampleID => ArrayIndex; map defining at what position in 
-                                // the second dimension of the datum array each sample is stored.
-    map<int, int> rev_sample_order;
 
 public:
     map<string, vector<LocusT *> > ordered_loci; // Loci ordered by genomic position
 
-    PopMap(int, int);
+    PopMap(const MetaPopInfo& mpopi, int n_loci);
     ~PopMap();
 
-    int populate(vector<int> &, map<int, LocusT*> &, vector<vector<CatMatch *> > &);
-    int order_loci(map<int, LocusT*> &);
-    int prune(set<int> &);
+    // Populates the PopMap based on sstack matches files.
+    // The catalog is modified (LocusT must be CSLocus, and
+    // members [cnt, hcnt, confounded_cnt] are modified).
+    int populate(map<int, LocusT*>& catalog, const vector<vector<CatMatch *> >& matches);
 
-    int loci_cnt() { return this->num_loci; }
-    int rev_locus_index(int index) { if (this->rev_locus_order.count(index) == 0) return -1; return this->rev_locus_order[index]; }
-    int sample_cnt() { return this->num_samples; }
-    int sample_index(int index) { if (this->sample_order.count(index) == 0) return -1; return this->sample_order[index]; }
-    int rev_sample_index(int index) { if (this->rev_sample_order.count(index) == 0) return -1; return this->rev_sample_order[index]; }
+    // Populates the PopMap based on VCF (SNP) records.
+    // The catalog is modified (LocusT must be CSLocus, and
+    // members [cnt, hcnt] are modified).
+    // N.B. The IDs of the loci in the catalog MUST be the same
+    // as the indexes in the records vector.
+    int populate(map<int, LocusT*>& catalog, const vector<VcfRecord>& records, const VcfHeader& header);
 
-    Datum **locus(int);
-    Datum  *datum(int, int);
-    bool    blacklisted(int, int);
+    int order_loci(const map<int, LocusT*>& catalog);
+    int prune(set<int>& loc_ids);
+
+    int loci_cnt() const { return this->num_loci; }
+    int locus_index(int id) const {return locus_order.at(id);}
+    int rev_locus_index(int index) const {try {return rev_locus_order.at(index);} catch(exception&) {return -1;}}
+
+    int sample_cnt() const { return metapopinfo.samples().size(); }
+    int sample_index(int id) const {try {return metapopinfo.get_sample_index(id);} catch (exception&) {return -1;}}
+    int rev_sample_index(int index) const {return metapopinfo.samples().at(index).id;}
+
+    Datum **locus(int id);
+    Datum  *datum(int loc_id, int sample_id);
+
+    bool    blacklisted(int loc_id, int sample_id);
 };
 
 template<class LocusT>
-PopMap<LocusT>::PopMap(int num_samples, int num_loci) {
+PopMap<LocusT>::PopMap(const MetaPopInfo& mpopi, int num_loci)
+: metapopinfo(mpopi)
+{
     this->data = new Datum **[num_loci];
 
     for (int i = 0; i < num_loci; i++) {
-        this->data[i] = new Datum *[num_samples];
+        this->data[i] = new Datum *[metapopinfo.samples().size()];
 
-        for (int j = 0; j < num_samples; j++)
+        for (size_t j = 0; j < metapopinfo.samples().size(); j++)
             this->data[i][j] = NULL;
     }
 
-    this->num_samples = num_samples;
     this->num_loci    = num_loci;
 }
 
 template<class LocusT>
 PopMap<LocusT>::~PopMap() {
     for (int i = 0; i < this->num_loci; i++) {
-        for (int j = 0; j < this->num_samples; j++)
+        for (int j = 0; j < metapopinfo.samples().size(); j++)
             delete this->data[i][j];
         delete [] this->data[i];
     }
@@ -155,22 +174,13 @@ PopMap<LocusT>::~PopMap() {
 }
 
 template<class LocusT>
-int PopMap<LocusT>::populate(vector<int> &sample_ids,
-                             map<int, LocusT*> &catalog,
-                             vector<vector<CatMatch *> > &matches) {
-    //
-    // Record the array position of each sample that we will load.
-    //
-    for (uint i = 0; i < sample_ids.size(); i++) {
-        this->sample_order[sample_ids[i]] = i;
-        this->rev_sample_order[i]         = sample_ids[i];
-    }
-
+int PopMap<LocusT>::populate(map<int, LocusT*> &catalog,
+                             const vector<vector<CatMatch *> > &matches) {
     //
     // Create an index showing what position each catalog locus is stored at in the datum 
     // array. Create a second index allowing ordering of Loci by genomic position.
     //
-    typename std::map<int, LocusT*>::iterator it;
+    typename std::map<int, LocusT*>::const_iterator it;
     uint i = 0;
     for (it = catalog.begin(); it != catalog.end(); it++) {
         this->locus_order[it->first] = i;
@@ -191,7 +201,7 @@ int PopMap<LocusT>::populate(vector<int> &sample_ids,
 
     for (i = 0; i < matches.size(); i++) {
         for (uint j = 0; j < matches[i].size(); j++) {
-            sample = this->sample_order[matches[i][j]->sample_id];
+            sample = metapopinfo.get_sample_index(matches[i][j]->sample_id);
 
             if (this->locus_order.count(matches[i][j]->cat_id) == 0)
                 continue;
@@ -260,11 +270,154 @@ int PopMap<LocusT>::populate(vector<int> &sample_ids,
 }
 
 template<class LocusT>
-int PopMap<LocusT>::order_loci(map<int, LocusT*> &catalog) 
+int PopMap<LocusT>::populate(map<int, LocusT*>& catalog,
+             const vector<VcfRecord>& records,
+             const VcfHeader& header) {
+
+    // Initalize [locus_order], [rev_locus_order].
+    size_t loc_index = 0;
+    for (typename map<int, LocusT*>::iterator
+            l = catalog.begin();
+            l != catalog.end();
+            ++l) {
+        locus_order[l->first] = loc_index;
+        rev_locus_order[loc_index] = l->first;
+        ++loc_index;
+    }
+
+    // Initialize [ordered_loci].
+    order_loci(catalog);
+
+    /*
+     * Fill the PopMap.
+     *
+     * We observe the following rules to create the Datums :
+     * [id] is the locus id.
+     * [len] is the locus length (expected to be one, for a SNP)
+     * [model] "E" or "O" according to the SAMPLE/GT field, or
+     *     "U" if the GT field is absent.
+     * [obshap] the nucleotide(s) observed for this SNP for this individual.
+     *     If one of a sample's VCF alleles is missing ('.') or has an index
+     *     corresponding to the special '*' allele, the Datum* is left to NULL.
+     *
+     * When no depth information is available, [tot_depth] and the [depths]
+     * of all alleles are set to 0.
+     * (n.b. the parsing of depth information in VCF is not implemented as
+     * of Mar 21, 2016.)
+     *
+     * When no likelihood information is available, [lnl] is set to 0.
+     * (n.b. the parsing of depth information in VCF is not implemented as
+     * of Mar 21, 2016.)
+     *
+     * The following members are left unset, on the premise that
+     * "populations" does not use them :
+     * corrected, genotype, trans_genotype
+     *
+     * [merge_partner] is set later by [merge_datums()] (in populations.cc).
+     * [snps] is only used by [write_vcf()] and [write_vcf_strict()], which
+     *     first call [populate_snp_calls()] then use the SNP data in the
+     *     datum.
+     */
+
+    loc_index = 0;
+    for (typename map<int, LocusT*>::iterator
+            l = catalog.begin();
+            l != catalog.end();
+            ++l) {
+        LocusT* loc = l->second;
+
+        const VcfRecord& rec = records[loc->id]; // n.b. assumes locus ID == record index.
+        int ad_index;
+        try {
+            ad_index = rec.index_of_gt_subfield("AD");
+        } catch (exception& e) {
+            ad_index = -1;
+        }
+
+        for (size_t s = 0; s < metapopinfo.samples().size(); ++s) {
+            size_t vcf_index = header.sample_indexes().at(metapopinfo.samples()[s].name);
+            const string& sample = rec.samples.at(vcf_index);
+
+            pair<int, int> gt = rec.parse_genotype(sample);
+            if (gt.first < 0
+                    || gt.second < 0
+                    || rec.alleles[gt.first]=="*"
+                    || rec.alleles[gt.second]=="*")
+                // Missing or incomplete genotype.
+                continue;
+
+            vector<int> ad;
+            if (ad_index != -1) {
+                string ad_str = rec.parse_gt_subfield(sample, ad_index);
+                size_t start = 0;
+                size_t coma;
+                try {
+                     while ((coma = ad_str.find(',', start)) != string::npos) {
+                         ad.push_back(std::stoi(ad_str.substr(start,coma)));
+                         if (ad.back() < 0)
+                             throw exception();
+                         start=coma+1;
+                     }
+                     ad.push_back(std::stoi(ad_str.substr(start)));
+                     if (ad.size() != rec.alleles.size())
+                         throw exception();
+                 } catch (exception& e) {
+                     cerr << "Warning: Badly formatted AD string '" << ad_str
+                          << "' at VCF record '" << rec.chrom << ":" << rec.pos << "'.\n";
+                     ad = vector<int>(rec.alleles.size(), 0);
+                 }
+            }
+
+            Datum* d = new Datum();
+            data[loc_index][s] = d;
+            ++loc->cnt;
+            ++loc->hcnt;
+
+            // id, len, lnl
+            d->id = loc->id;
+            d->len = loc->len;
+            d->lnl = 0;
+
+            // model, obshap, depth
+            d->model = new char[2];
+            if (gt.first == gt.second) {
+                strcpy(d->model, "O");
+                const string& allele = rec.alleles[gt.first];
+                d->obshap.push_back(new char[allele.size()+1]);
+                strcpy(d->obshap[0], allele.c_str());
+                if (ad_index != -1)
+                    d->depth = { ad[gt.first] };
+                else
+                    d->depth = {0};
+            } else {
+                strcpy(d->model, "E");
+                const string& allele1 = rec.alleles[gt.first];
+                const string& allele2 = rec.alleles[gt.second];
+                d->obshap.push_back(new char[allele1.size()+1]);
+                d->obshap.push_back(new char[allele2.size()+1]);
+                strcpy(d->obshap[0], allele1.c_str());
+                strcpy(d->obshap[1], allele2.c_str());
+                if (ad_index != -1)
+                    d->depth = {ad[gt.first], ad[gt.second]};
+                else
+                    d->depth = {0, 0};
+            }
+
+            // tot_depth
+            d->tot_depth = std::accumulate(d->depth.begin(), d->depth.end(), 0);
+        }
+        ++loc_index;
+    }
+
+    return 0;
+}
+
+template<class LocusT>
+int PopMap<LocusT>::order_loci(const map<int, LocusT*> &catalog)
 {
     this->ordered_loci.clear();
 
-    typename std::map<int, LocusT*>::iterator it;
+    typename std::map<int, LocusT*>::const_iterator it;
 
     for (it = catalog.begin(); it != catalog.end(); it++) {
         if (strlen(it->second->loc.chr) > 0)
@@ -294,20 +447,16 @@ int PopMap<LocusT>::prune(set<int> &remove_ids) {
 
         loc_id = this->rev_locus_order[i];
 
-        //
-        // Keep this locus.
-        //
         if (remove_ids.count(loc_id) == 0) {
+            // Keep this locus.
             d[j] = this->data[i];
             new_loc_order[loc_id] = j;
             new_rev_loc_order[j] = loc_id;
             j++;
 
         } else {
-            //
             // Remove this locus.
-            //
-            for (int k = 0; k < this->num_samples; k++)
+            for (size_t k = 0; k < metapopinfo.samples().size(); k++)
                 delete this->data[i][k];
             delete [] this->data[i];
         }
@@ -345,13 +494,13 @@ int PopMap<LocusT>::prune(set<int> &remove_ids) {
 }
 
 template<class LocusT>
-Datum **PopMap<LocusT>::locus(int locus) {
-    return this->data[this->locus_order[locus]];
+Datum **PopMap<LocusT>::locus(int id) {
+    return this->data[this->locus_order[id]];
 }
 
 template<class LocusT>
-Datum  *PopMap<LocusT>::datum(int locus, int sample) {
-    return this->data[this->locus_order[locus]][this->sample_order[sample]];
+Datum  *PopMap<LocusT>::datum(int loc_id, int sample_id) {
+    return this->data[this->locus_order[loc_id]][metapopinfo.get_sample_index(sample_id)];
 }
 
 template<class LocusT>
