@@ -48,8 +48,11 @@ int main (int argc, char* argv[]) {
 
     uint sample_cnt = samples.size();
 
-    cerr << "Number of mismatches allowed between stacks: " << ctag_dist << "\n"
-	 << "Loci matched based on " << (search_type == sequence ? "sequence identity" : "genomic location") << ".\n"
+    cerr << "cstacks paramters selected:\n"
+	 << "  Loci matched based on " << (search_type == sequence ? "sequence identity" : "genomic location") << ".\n";
+    if (search_type == sequence)
+        cerr << "  Number of mismatches allowed between stacks: " << ctag_dist << "\n";
+    cerr << "  Gapped alignments: " << (gapped_alignments ? "enabled" : "disabled") << "\n"
 	 << "Constructing catalog from " << sample_cnt << " samples.\n";
 
     //
@@ -173,7 +176,7 @@ int update_catalog_index(map<int, CLocus *> &catalog, map<string, int> &cat_inde
 	snprintf(id, id_len - 1, "%s|%d|%c", 
 		 j->second->loc.chr, 
 		 j->second->loc.bp, 
-		 j->second->loc.strand == plus ? '+' : '-');
+		 j->second->loc.strand == strand_plus ? '+' : '-');
 
 	if (cat_index.count(id) == 0) {
 	    cat_index[id] = j->first;
@@ -186,7 +189,9 @@ int update_catalog_index(map<int, CLocus *> &catalog, map<string, int> &cat_inde
     return 0;
 }
 
-int characterize_mismatch_snps(CLocus *catalog_tag, QLocus *query_tag) {
+int
+characterize_mismatch_snps(CLocus *catalog_tag, QLocus *query_tag)
+{
     set<int> snp_cols;
     uint i;
     for (i = 0; i < catalog_tag->snps.size(); i++)
@@ -247,7 +252,7 @@ merge_matches(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, pair<int,
     CLocus *ctag;
     QLocus *qtag;
     string  cseq, qseq, cigar_str;
-    int     cseq_len, qseq_len, match_index;
+    int     cseq_len, match_index;
     vector<pair<char, uint> > cigar;
 
     GappedAln *aln = new GappedAln();
@@ -322,12 +327,40 @@ merge_matches(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, pair<int,
         cigar_str = "";
 
         for (uint k = 0; k < qtag->matches.size(); k++)
-            if (qtag->matches[k]->cat_id == min_cat_id) {
+            if ((int)qtag->matches[k]->cat_id == min_cat_id) {
                 cigar_str   = qtag->matches[k]->cigar;
                 match_index = k;
                 break;
             }
 
+        //
+        // If we have already matched a query locus to this catalog locus for the current
+        // sample, we must re-align the sequences in case changes have been made to the
+        // sequence by the previous matching sequence.
+        //
+        if (gapped_alignments && ctag->match_cnt > 0) {
+            string query_allele, query_seq, cat_allele, cat_seq;
+            // cerr << "    Warning: Catalog locus " << ctag->id
+            //      << ", Sample " << qtag->sample_id << ", locus " << qtag->id
+            //      << "; sequence length has changed since original alignment: "
+            //      << qseq_len << " <-> " << ctag->len
+            //      << "; re-aligning.\n";
+
+            //
+            // Find the proper query allele to align against the catalog. We can align
+            // against the catalog consensus because the allele strings may have changed.
+            //
+            query_allele = qtag->matches[match_index]->query_type;
+            for (uint k = 0; k < qtag->strings.size(); k++)
+                if (qtag->strings[k].first == query_allele) {
+                    query_seq = qtag->strings[k].second;
+                    break;
+                }
+            aln->init(ctag->len, qtag->len);
+            aln->align(ctag->con, query_seq);
+            cigar_str = invert_cigar(aln->result().cigar);
+        }
+
         bool gapped_aln = false;
         if (cigar_str.length() > 0)
             gapped_aln = true;
@@ -337,32 +370,6 @@ merge_matches(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, pair<int,
         // Adjust the postition of any SNPs that were shifted down sequence due to a gap.
         //
         if (gapped_aln) {
-            qseq_len = parse_cigar(cigar_str.c_str(), cigar);
-
-            if (ctag->match_cnt > 0) {
-                string query_allele, query_seq, cat_allele, cat_seq;
-                // cerr << "    Warning: Catalog locus " << ctag->id
-                //      << ", Sample " << qtag->sample_id << ", locus " << qtag->id
-                //      << "; sequence length has changed since original alignment: "
-                //      << qseq_len << " <-> " << ctag->len
-                //      << "; re-aligning.\n";
-
-                //
-                // Find the proper query allele to align against the catalog. We can align
-                // against the catalog consensus because the allele strings may have changed.
-                //
-                query_allele = qtag->matches[match_index]->query_type;
-                for (uint k = 0; k < qtag->strings.size(); k++)
-                    if (qtag->strings[k].first == query_allele) {
-                        query_seq = qtag->strings[k].second;
-                        break;
-                    }
-                aln->init(ctag->len, qtag->len);
-                aln->align(ctag->con, query_seq);
-                cigar_str = invert_cigar(aln->result().cigar);
-                parse_cigar(cigar_str.c_str(), cigar);
-            }
-
             qseq      = apply_cigar_to_seq(qtag->con, cigar);
             adjust_snps_for_gaps(cigar, qtag);
 
@@ -375,7 +382,7 @@ merge_matches(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, pair<int,
             // If the alignment modified the catalog locus, record it so we can re-align
             // any other matching sequences from this sample.
             //
-            if (cseq_len > ctag->len)
+            if ((uint)cseq_len > ctag->len)
                 ctag->match_cnt++;
 
             //
@@ -542,7 +549,7 @@ int find_kmer_matches_by_sequence(map<int, CLocus *> &catalog, map<int, QLocus *
 		// generate, multiple, spurious hits in sequences with multiple copies of the same kmer.
 		//
 		uniq_kmers.clear();
-                for (uint j = 0; j < num_kmers; j++)
+                for (int j = 0; j < num_kmers; j++)
 		    uniq_kmers.insert(kmers[j]);
 
 		hits.clear();
@@ -581,7 +588,7 @@ int find_kmer_matches_by_sequence(map<int, CLocus *> &catalog, map<int, QLocus *
 		    hit_cnt   = 0;
 		    allele_id = prev_id;
 
-		    while (hits[index] == prev_id) {
+		    while ((uint)hits[index] == prev_id) {
 			hit_cnt++;
 			index++;
 		    }
@@ -589,7 +596,7 @@ int find_kmer_matches_by_sequence(map<int, CLocus *> &catalog, map<int, QLocus *
 		    if (index < hits_size)
 			prev_id = hits[index];
 
-		    if (hit_cnt >= min_hits)
+		    if (hit_cnt >= (uint)min_hits)
 			ordered_hits.push_back(make_pair(allele_id, hit_cnt));
 
         	} while (index < hits_size);
@@ -720,7 +727,7 @@ search_for_gaps(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, double
 		// generate, multiple, spurious hits in sequences with multiple copies of the same kmer.
 		//
 		uniq_kmers.clear();
-                for (uint j = 0; j < num_kmers; j++)
+                for (int j = 0; j < num_kmers; j++)
 		    uniq_kmers.insert(kmers[j]);
 
                 hits.clear();
@@ -759,7 +766,7 @@ search_for_gaps(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, double
 		    hit_cnt   = 0;
 		    allele_id = prev_id;
 
-		    while (hits[index] == prev_id) {
+		    while ((uint)hits[index] == prev_id) {
 			hit_cnt++;
 			index++;
 		    }
@@ -767,7 +774,7 @@ search_for_gaps(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, double
 		    if (index < hits_size)
 			prev_id = hits[index];
 
-		    if (hit_cnt >= min_hits)
+		    if (hit_cnt >= (uint)min_hits)
 			ordered_hits.push_back(make_pair(allele_id, hit_cnt));
 
         	} while (index < hits_size);
@@ -786,7 +793,7 @@ search_for_gaps(map<int, CLocus *> &catalog, map<int, QLocus *> &sample, double
 		top_hit = ordered_hits[0].second;
                 stop    = 1;
 		for (uint j = 1; j < ordered_hits.size(); j++)
-		    if (ordered_hits[j].second < top_hit) {
+		    if ((uint)ordered_hits[j].second < top_hit) {
 			stop = j;
 			break;
 		    }
@@ -927,7 +934,7 @@ int find_matches_by_genomic_loc(map<string, int> &cat_index, map<int, QLocus *>
 	    snprintf(id, id_len - 1, "%s|%d|%c", 
 		     i->second->loc.chr, 
 		     i->second->loc.bp, 
-		     i->second->loc.strand == plus ? '+' : '-');
+		     i->second->loc.strand == strand_plus ? '+' : '-');
 
 	    if (cat_index.count(id) > 0)
 		i->second->add_match(cat_index[id], "", "", 0);
@@ -1531,7 +1538,7 @@ write_simple_output(CLocus *tag, ofstream &cat_file, ofstream &snp_file, ofstrea
 	tag->id      << "\t" <<
         tag->loc.chr << "\t" <<
         tag->loc.bp  << "\t" <<
-        (tag->loc.strand == plus ? "+" : "-") << "\t" <<
+        (tag->loc.strand == strand_plus ? "+" : "-") << "\t" <<
 	"consensus"  << "\t" <<
 	"0"          << "\t" <<
 	sources      << "\t" <<
@@ -1608,7 +1615,7 @@ write_gzip_output(CLocus *tag, gzFile &cat_file, gzFile &snp_file, gzFile &all_f
 	tag->id      << "\t" <<
         tag->loc.chr << "\t" <<
         tag->loc.bp  << "\t" <<
-        (tag->loc.strand == plus ? "+" : "-") << "\t" <<
+        (tag->loc.strand == strand_plus ? "+" : "-") << "\t" <<
 	"consensus"  << "\t" <<
 	"0"          << "\t" <<
 	sources      << "\t" <<
