@@ -26,7 +26,7 @@
 uint 
 Locus::sort_bp(uint k) 
 {
-    if (this->loc.strand == plus)
+    if (this->loc.strand == strand_plus)
         return this->loc.bp + k;
     else
         return (k == 0 ? this->loc.bp - this->len + 1 : this->loc.bp - k);
@@ -54,6 +54,19 @@ Locus::add_consensus(const char *seq)
     return 0;
 }
 
+int 
+Locus::add_model(const char *seq) 
+{
+    if (this->model != NULL)
+        delete [] this->model;
+
+    this->model = new char[this->len + 1];
+    strncpy(this->model, seq, this->len);
+    this->model[this->len] = '\0';
+    
+    return 0;
+}
+
 int 
 Locus::populate_alleles() 
 {
