@@ -23,8 +23,12 @@
 // across a population of samples.
 //
 
+#include "MetaPopInfo.h"
+
 #include "rxstacks.h"
 
+typedef MetaPopInfo::Sample Sample;
+
 // Global variables to hold command-line options.
 int    num_threads = 1;
 int    batch_id    = 0;
@@ -89,9 +93,12 @@ int main (int argc, char* argv[]) {
     omp_set_num_threads(num_threads);
     #endif
 
-    vector<pair<int, string> > files;
-    if (!build_file_list(files))
-	exit(1);
+    MetaPopInfo mpopi;
+    mpopi.init_directory(in_path);
+    if (mpopi.samples().empty()) {
+        cerr << "Error: Failed to find sample files in directory '" << in_path << "'.\n";
+        return -1;
+    }
 
     //
     // Open and initialize the log files.
@@ -124,33 +131,46 @@ int main (int argc, char* argv[]) {
     // Load matches to the catalog
     //
     vector<vector<CatMatch *> > catalog_matches;
-    map<int, string>            samples;
-    vector<int>                 sample_ids;
-    for (uint i = 0; i < files.size(); i++) {
-	vector<CatMatch *> m;
-	load_catalog_matches(in_path + files[i].second, m);
+    vector<size_t> samples_to_remove;
+    set<size_t> seen_samples;
+    for (size_t i=0; i<mpopi.samples().size(); ++i) {
+        catalog_matches.push_back(vector<CatMatch*>());
+        vector<CatMatch *>& m = catalog_matches.back();
 
-	if (m.size() == 0) {
-	    cerr << "Warning: unable to find any matches in file '" << files[i].second << "', excluding this sample from population analysis.\n";
-	    continue;
-	}
+        const Sample& sample = mpopi.samples()[i];
+        load_catalog_matches(in_path + sample.name, m);
 
-	catalog_matches.push_back(m);
-	if (samples.count(m[0]->sample_id) == 0) {
-	    samples[m[0]->sample_id] = files[i].second;
-	    sample_ids.push_back(m[0]->sample_id);
-	} else {
-	    cerr << "Fatal error: sample ID " << m[0]->sample_id << " occurs twice in this data set, likely the pipeline was run incorrectly.\n";
-	    exit(0);
-	}
+        if (m.size() == 0) {
+            cerr << "Warning: Absent or malformed matches file '"
+                 << sample.name << ".matches.tsv(.gz)"
+                 <<"', excluding this sample from population analysis.\n";
+            samples_to_remove.push_back(i);
+            catalog_matches.pop_back(); // n.b. Index shift will be resolved by the call to MetaPopInfo::delete_samples().
+            continue;
+        }
+
+        size_t sample_id = m[0]->sample_id;
+        if (seen_samples.count(sample_id) > 0) {
+            cerr << "Error: sample ID " << sample_id << " occurs twice in this data set, likely the pipeline was run incorrectly.\n";
+            return -1;
+        }
+        seen_samples.insert(sample_id);
+        mpopi.set_sample_id(i, sample_id);
     }
+    mpopi.delete_samples(samples_to_remove);
+    if (mpopi.samples().size() == 0) {
+        cerr << "Error: Couln't find any matches files.\n";
+        return -1;
+    }
+    // [mpopi] is definitive.
+    cerr << "Working on " << mpopi.samples().size() << " samples.\n";
 
     //
     // Create the population map
     // 
-    cerr << "Populating observed haplotypes for " << sample_ids.size() << " samples, " << catalog.size() << " loci.\n";
-    PopMap<CSLocus> *pmap = new PopMap<CSLocus>(sample_ids.size(), catalog.size());
-    pmap->populate(sample_ids, catalog, catalog_matches);
+    cerr << "Populating observed haplotypes for " << mpopi.samples().size() << " samples, " << catalog.size() << " loci.\n";
+    PopMap<CSLocus> *pmap = new PopMap<CSLocus>(mpopi, catalog.size());
+    pmap->populate(catalog, catalog_matches);
 
     //
     // Sum haplotype counts across the population for each catalog locus.
@@ -162,17 +182,15 @@ int main (int argc, char* argv[]) {
     //
     calc_lnl_means(catalog, pmap);
 
-    int    catalog_id, sample_id, tag_id;
-    string file;
+    int    catalog_id, tag_id;
 
     //
     // Process samples matched to the catalog, one by one.
     //
-    for (uint i = 0; i < catalog_matches.size(); i++) {
-	sample_id = catalog_matches[i][0]->sample_id;
-	file      = samples[sample_id];
+    for (uint i = 0; i < mpopi.samples().size(); i++) {
+        const Sample& sample = mpopi.samples()[i];
 
-	cerr << "Loading stacks from sample " << file << " [" << i+1 << " of " << catalog_matches.size() << "]...\n";
+	cerr << "Loading stacks from sample " << sample.name << " [" << i+1 << " of " << mpopi.samples().size() << "]...\n";
 
 	//////
 	//////
@@ -182,12 +200,12 @@ int main (int argc, char* argv[]) {
 
 	map<int, Locus *> stacks;
 	int res;
-	if ((res = load_loci(in_path + file, stacks, true, true, compressed)) == 0) {
-	    cerr << "Unable to load sample file '" << file << "'\n";
+	if ((res = load_loci(in_path + sample.name, stacks, true, true, compressed)) == 0) {
+	    cerr << "Unable to load sample file '" << sample.name << "'\n";
 	    continue;
 	}
 
-	cerr << "Making corrections to sample " << file << "...";
+	cerr << "Making corrections to sample " << sample.name << "...";
 	
 	set<pair<int, int> >           uniq_matches;
 	set<pair<int, int> >::iterator it;
@@ -228,6 +246,11 @@ int main (int argc, char* argv[]) {
 	    Datum   *d;
 	    Locus   *loc;
 	    CSLocus *cloc;
+            uint     seq_len;
+            string   seq, model;
+            char    *adj_seq;
+            vector<pair<char, uint> > cigar;
+            vector<char *>            reads;
 
             #pragma omp for schedule(dynamic, 1) reduction(+:nuc_cnt) reduction(+:unk_hom_cnt) reduction(+:unk_het_cnt) \
 		reduction(+:hom_unk_cnt) reduction(+:het_unk_cnt) reduction(+:hom_het_cnt) reduction(+:het_hom_cnt) \
@@ -257,7 +280,7 @@ int main (int argc, char* argv[]) {
 		    continue;
 		}
 
-		d = pmap->datum(catalog_id, sample_id);
+		d = pmap->datum(catalog_id, sample.id);
 
 		if (d == NULL) continue;
 
@@ -267,6 +290,27 @@ int main (int argc, char* argv[]) {
 		    continue;
 		}
 
+                //
+                // If this locus was matched to the catalog using a gapped alignment, adjust the sequence
+                // and SNP positions.
+                //
+                if (d->cigar != NULL) {
+                    seq_len = parse_cigar(d->cigar, cigar);
+                    seq     = apply_cigar_to_seq(loc->con, cigar);
+                    model   = apply_cigar_to_model_seq(loc->model, cigar);
+                    loc->add_consensus(seq.c_str());
+                    loc->add_model(model.c_str());
+                    adjust_and_add_snps_for_gaps(cigar, loc);
+
+                    for (uint k = 0; k < loc->reads.size(); k++) {
+                        reads.push_back(loc->reads[k]);
+
+                        adj_seq = new char[seq_len + 1];
+                        apply_cigar_to_seq(adj_seq, seq_len, loc->reads[k], cigar);
+                        loc->reads[k] = adj_seq;
+                    }
+                }
+
 		prune_nucleotides(cloc, loc, d, log_snp_fh,
 				  nuc_cnt,
 				  unk_hom_cnt, unk_het_cnt, 
@@ -284,6 +328,25 @@ int main (int argc, char* argv[]) {
 		    if (loc->blacklisted)
 			blacklist_cnt++;
 		}
+
+                //
+                // If this locus was matched to the catalog using a gapped alignment, de-adjust the sequence
+                // and SNP positions for writing back to disk.
+                //
+                if (d->cigar != NULL) {
+                    seq   = remove_cigar_from_seq(loc->con, cigar);
+                    model = remove_cigar_from_seq(loc->model, cigar);
+                    loc->add_consensus(seq.c_str());
+                    loc->add_model(model.c_str());
+                    remove_snps_from_gaps(cigar, loc);
+
+                    for (uint k = 0; k < loc->reads.size(); k++) {
+                        adj_seq = loc->reads[k];
+                        loc->reads[k] = reads[k];
+                        delete [] adj_seq;
+                    }
+                    reads.clear();
+                }
 	    }
         }
 
@@ -305,7 +368,7 @@ int main (int argc, char* argv[]) {
 	     << "Blacklisted: " << lnl_cnt            << " loci due to log likelihoods below threshold.\n"
 	     << "Blacklisted: " << conf_loci_cnt      << " confounded loci.\n";
 
-	log_fh << file           << "\t"
+	log_fh << sample.name           << "\t"
 	       << nuc_cnt        << "\t"
 	       << total          << "\t"
 	       << unk_hom_cnt    << "\t"
@@ -325,7 +388,7 @@ int main (int argc, char* argv[]) {
 	//
 	// Rewrite stacks, model outputs, and haplotypes.
 	//
-	write_results(file, stacks);
+	write_results(sample.name, stacks);
 
 	//
 	// Free up memory
@@ -845,8 +908,19 @@ prune_nucleotides(CSLocus *cloc, Locus *loc, Datum *d, ofstream &log_fh, unsigne
     nuc_cnt += loc->len;
 
     for (uint i = 0; i < loc->snps.size() && i < cloc->snps.size(); i++) {
+
+        //
+        // Safety checks.
+        //
+        if (loc->snps[i]->col != cloc->snps[i]->col)
+            cerr << "Warning: comparing mismatched SNPs in catalog locus " << cloc->id
+                 << " and sample " << loc->sample_id << ", locus " << loc->id << "; col: " << loc->snps[i]->col << "\n";
+        if (loc->snps[i]->type == snp_type_het && cloc->snps[i]->type == snp_type_hom)
+            cerr << "Warning: sample locus is variable while catalog locus is fixed; catalog locus " << cloc->id
+                 << " and sample " << loc->sample_id << ", locus " << loc->id << "; col: " << loc->snps[i]->col << "\n";
+        
 	//
-	// Either their is an unknown call in locus, or, there is a snp in the catalog and any state in the locus.
+	// Either there is an unknown call in locus, or, there is a snp in the catalog and any state in the locus.
 	//
 	if ((loc->snps[i]->type == snp_type_unk) || 
 	    (cloc->snps[i]->type == snp_type_het && loc->snps[i]->type == snp_type_hom)) {
@@ -854,11 +928,13 @@ prune_nucleotides(CSLocus *cloc, Locus *loc, Datum *d, ofstream &log_fh, unsigne
 	    // cerr << "  Looking at SNP call in tag " << loc->id << " at position " << i << "; col: " << loc->snps[i]->col << "\n"
 	    // 	 << "    Catalog column: " << cloc->snps[i]->col << " (" << i << "); Sample column: " << loc->snps[i]->col << " (" << i << ")\n"
 	    // 	 << "    Sample has model call type: " << (loc->snps[i]->type == snp_type_unk ? "Unknown" : "Homozygous") << "; nucleotides: '" 
-	    // 	 << loc->snps[i]->rank_1 << "' and '" << loc->snps[i]->rank_2 << "'\n"
+	    // 	 << loc->snps[i]->rank_1 << "' and '" << loc->snps[i]->rank_2 << "'; model call: " << loc->model[loc->snps[i]->col] << "\n"
 	    // 	 << "    Catalog has model call type: " << (cloc->snps[i]->type == snp_type_het ? "Heterozygous" : "Homozygous") << "; nucleotides: '" 
 	    // 	 << cloc->snps[i]->rank_1 << "' and '" << cloc->snps[i]->rank_2 << "'\n";
 
-	    if (loc->snps[i]->rank_1 == 'N' || cloc->snps[i]->rank_1 == 'N') continue;
+	    if (loc->snps[i]->rank_1 == 'N' || cloc->snps[i]->rank_1 == 'N' ||
+                loc->snps[i]->rank_1 == '-' || cloc->snps[i]->rank_1 == '-')
+                continue;
 
 	    cnucs.insert(cloc->snps[i]->rank_1);
 	    if (cloc->snps[i]->rank_2 != 0) cnucs.insert(cloc->snps[i]->rank_2);
@@ -895,22 +971,21 @@ prune_nucleotides(CSLocus *cloc, Locus *loc, Datum *d, ofstream &log_fh, unsigne
 	    //
 	    invoke_model(loc, i, nucs);
 
-	    if (verbose) {
-		#pragma omp critical
-		log_model_calls(loc, log_fh,
-				unk_hom_cnt, unk_het_cnt, 
-				hom_unk_cnt, het_unk_cnt, 
-				hom_het_cnt, het_hom_cnt);
-	    } else {
-		log_model_calls(loc, log_fh,
-				unk_hom_cnt, unk_het_cnt, 
-				hom_unk_cnt, het_unk_cnt, 
-				hom_het_cnt, het_hom_cnt);
-	    }
+            cnucs.clear();
 	}
+    }
 
-	nucs.clear();
-	cnucs.clear();
+    if (verbose) {
+        #pragma omp critical
+        log_model_calls(loc, log_fh,
+                        unk_hom_cnt, unk_het_cnt, 
+                        hom_unk_cnt, het_unk_cnt, 
+                        hom_het_cnt, het_hom_cnt);
+    } else {
+        log_model_calls(loc, log_fh,
+                        unk_hom_cnt, unk_het_cnt, 
+                        hom_unk_cnt, het_unk_cnt, 
+                        hom_het_cnt, het_hom_cnt);
     }
 
     //
@@ -1243,7 +1318,7 @@ write_results(string file, map<int, Locus *> &m)
 	     << tag_1->id << "\t" 
              << tag_1->loc.chr << "\t"
              << tag_1->loc.bp << "\t"
-             << (tag_1->loc.strand == plus ? "+" : "-") << "\t"
+             << (tag_1->loc.strand == strand_plus ? "+" : "-") << "\t"
 	     << "consensus" << "\t" 
 	     << "\t"
 	     << "\t" 
@@ -1295,13 +1370,14 @@ write_results(string file, map<int, Locus *> &m)
 		 << tag_1->sample_id    << "\t" 
 		 << tag_1->id           << "\t\t\t\t";
 
-	    if (tag_1->comp_type[j] == primary)
-		sstr << "primary" << "\t";
-	    else
-		sstr << "secondary" << "\t";
+	    if (tag_1->comp_type[j] == primary) {
+		sstr << "primary" << "\t"
+                     << tag_1->comp_cnt[j]  << "\t";
+            } else {
+		sstr << "secondary" << "\t\t";
+            }
 
-	    sstr << tag_1->comp_cnt[j]  << "\t" 
-		 << tag_1->comp[j]      << "\t" 
+	    sstr << tag_1->comp[j]      << "\t" 
 		 << tag_1->reads[j]     << "\t\t\t\t\n";
 	}
 
@@ -1372,50 +1448,6 @@ write_results(string file, map<int, Locus *> &m)
     return 0;
 }
 
-int build_file_list(vector<pair<int, string> > &files) {
-    vector<string> parts;
-    string f;
-
-    //
-    // Read all the files from the Stacks directory.
-    //
-    uint   pos;
-    string file;
-    struct dirent *direntry;
-
-    DIR *dir = opendir(in_path.c_str());
-
-    if (dir == NULL) {
-	cerr << "Unable to open directory '" << in_path << "' for reading.\n";
-	exit(1);
-    }
-
-    while ((direntry = readdir(dir)) != NULL) {
-	file = direntry->d_name;
-
-	if (file == "." || file == "..")
-	    continue;
-
-	if (file.substr(0, 6) == "batch_")
-	    continue;
-
-	pos = file.rfind(".tags.tsv");
-	if (pos < file.length())
-	    files.push_back(make_pair(1, file.substr(0, pos)));
-    }
-
-    closedir(dir);
-
-    if (files.size() == 0) {
-	cerr << "Unable to locate any input files to process within '" << in_path << "'\n";
-	return 0;
-    }
-
-    cerr << "Found " << files.size() << " input file(s).\n";
-
-    return 1;
-}
-
 int
 fill_catalog_snps(map<int, CSLocus *> &catalog)
 {
