@@ -167,7 +167,7 @@ find_matches_by_genomic_loc(map<int, Locus *> &sample_1, map<int, QLocus *> &sam
         snprintf(id, id_len - 1, "%s|%d|%c", 
 		 j->second->loc.chr, 
 		 j->second->loc.bp, 
-		 j->second->loc.strand == plus ? '+' : '-');
+		 j->second->loc.strand == strand_plus ? '+' : '-');
         locations[id].insert(j->second->id);
     }
 
@@ -198,7 +198,7 @@ find_matches_by_genomic_loc(map<int, Locus *> &sample_1, map<int, QLocus *> &sam
 	    snprintf(id, id_len - 1, "%s|%d|%c", 
 		     i->second->loc.chr, 
 		     i->second->loc.bp, 
-		     i->second->loc.strand == plus ? '+' : '-');
+		     i->second->loc.strand == strand_plus ? '+' : '-');
 
 	    if (locations.count(id) > 0) {
 		Locus *tag;
@@ -799,7 +799,8 @@ search_for_gaps(map<int, Locus *> &catalog, map<int, QLocus *> &sample,
 
 	initialize_kmers(gapped_kmer_len, num_kmers, kmers);
 
-        #pragma omp for schedule(dynamic) reduction(+:matches) reduction(+:nomatches) reduction(+:mmatches) reduction(+:gapped_aln) reduction(+:ver_hap) reduction(+:tot_hap) reduction(+:bad_aln) reduction(+:no_haps)
+        #pragma omp for schedule(dynamic) reduction(+:matches) reduction(+:nomatches) reduction(+:mmatches) reduction(+:gapped_aln) reduction(+:ver_hap) \
+                                          reduction(+:tot_hap) reduction(+:bad_aln) reduction(+:no_haps)
         for (uint i = 0; i < keys.size(); i++) {
             query = sample[keys[i]];
 
@@ -829,7 +830,7 @@ search_for_gaps(map<int, Locus *> &catalog, map<int, QLocus *> &sample,
 		// generate, multiple, spurious hits in sequences with multiple copies of the same kmer.
 		//
 		uniq_kmers.clear();
-                for (uint j = 0; j < num_kmers; j++)
+                for (int j = 0; j < num_kmers; j++)
 		    uniq_kmers.insert(kmers[j]);
 
 		hits.clear();
@@ -868,7 +869,7 @@ search_for_gaps(map<int, Locus *> &catalog, map<int, QLocus *> &sample,
 		    hit_cnt   = 0;
 		    allele_id = prev_id;
 
-		    while (hits[index] == prev_id) {
+		    while ((uint)hits[index] == prev_id) {
 			hit_cnt++;
 			index++;
 		    }
@@ -876,7 +877,7 @@ search_for_gaps(map<int, Locus *> &catalog, map<int, QLocus *> &sample,
 		    if (index < hits_size)
 			prev_id = hits[index];
 
-		    if (hit_cnt >= min_hits)
+		    if (hit_cnt >= (uint)min_hits)
 			ordered_hits.push_back(make_pair(allele_id, hit_cnt));
 
         	} while (index < hits_size);
@@ -895,7 +896,7 @@ search_for_gaps(map<int, Locus *> &catalog, map<int, QLocus *> &sample,
 		top_hit = ordered_hits[0].second;
                 stop    = 1;
 		for (uint j = 1; j < ordered_hits.size(); j++)
-		    if (ordered_hits[j].second < top_hit) {
+		    if ((uint)ordered_hits[j].second < top_hit) {
 			stop = j;
 			break;
 		    }
@@ -1024,7 +1025,7 @@ verify_gapped_match(map<int, Locus *> &catalog, QLocus *query,
     qseq = apply_cigar_to_seq(query->con, cigar);
     query->add_consensus(qseq.c_str());
 
-    int min_tag_len = query_len > cat->len ? query_len : cat->len;
+    int min_tag_len = (uint)query_len > cat->len ? query_len : cat->len;
 
     vector<SNP *>::iterator i, j;
     bool found;
@@ -1034,7 +1035,7 @@ verify_gapped_match(map<int, Locus *> &catalog, QLocus *query,
 	//
 	// SNP occurs in a column that is beyond the length of the catalog
 	//
-	if ((*i)->col > min_tag_len - 1)
+	if ((int)(*i)->col > min_tag_len - 1)
 	    continue;
 
 	for (j = cat->snps.begin(); j != cat->snps.end(); j++) {
@@ -1051,7 +1052,7 @@ verify_gapped_match(map<int, Locus *> &catalog, QLocus *query,
     }
 
     //
-    // 4. Assign the allele hits after verifying there is a match between catalog and query allele..
+    // 4. Assign the allele hits after verifying there is a match between catalog and query allele.
     //
     for (query_it = query_hits.begin(); query_it != query_hits.end(); query_it++) {
         query_allele = query_it->first;
